@@ -10,7 +10,7 @@ package POE::Component::Client::opentick::Util;
 #
 
 use strict;
-use Carp qw( carp longmess );
+use Carp qw( carp );
 use Data::Dumper;
 
 use POE::Component::Client::opentick::Error;
@@ -23,7 +23,7 @@ BEGIN {
     our @EXPORT = qw( pack_binary unpack_binary count_fields check_fields
                       dump_hex    pack_macaddr  is_error     pack_bytes
                       asc2longlong  );
-    $VERSION    = '0.02';
+    $VERSION    = '0.03';
 }
 
 ###
